==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/DockManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { DockManagerLayout } from "./DockManagerLayout";
import { DockManagerPane } from "./DockManagerPane";
import { DockManagerPoint } from "./DockManagerPoint";
import { ContentPane } from "./ContentPane";
import { DockManagerShowHeaderIconOnHover_$type } from "./DockManagerShowHeaderIconOnHover";
import { DockManagerResourceStrings } from "./DockManagerResourceStrings";
import { LayoutChangeEventArgs } from "./LayoutChangeEventArgs";
/**
 * @hidden
 */
var DockManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockManager, _super);
    function DockManager() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.layoutChange = null;
        _this.i = new WCNativeHelper();
        _this.o = null;
        return _this;
    }
    DockManager.prototype.layoutChangeChanged = function () {
        var _this = this;
        if (this.layoutChange != null) {
            this.j.q("layoutChange", function (a) { return _this.layoutChange(_this, LayoutChangeEventArgs.b(_this.b)); }, false);
        }
        else {
            this.j.t("layoutChange");
        }
    };
    Object.defineProperty(DockManager.prototype, "j", {
        get: function () {
            return this.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "nativeElement", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.i.n = this.o;
        },
        enumerable: false,
        configurable: true
    });
    DockManager.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockManager.prototype, "b", {
        get: function () {
            var ret_ = this.j.l("layout", function (a) { return new DockManagerLayout(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("layout", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "c", {
        get: function () {
            var ret_ = this.j.l("draggedPane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("draggedPane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "e", {
        get: function () {
            var ret_ = this.j.l("dropPosition", function (a) { return new DockManagerPoint(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("dropPosition", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "a", {
        get: function () {
            var ret_ = this.j.l("activePane", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("activePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "m", {
        get: function () {
            var ret_ = this.j.m("allowMaximize");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("allowMaximize", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "g", {
        get: function () {
            var ret_ = this.j.m("showHeaderIconOnHover");
            ret_ = enumGetBox(DockManagerShowHeaderIconOnHover_$type, EnumUtil.getEnumValue(DockManagerShowHeaderIconOnHover_$type, this.j.f(DockManagerShowHeaderIconOnHover_$type, ret_)));
            return EnumUtil.getEnumValue(DockManagerShowHeaderIconOnHover_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DockManagerShowHeaderIconOnHover_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.j.u("showHeaderIconOnHover", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "d", {
        get: function () {
            var ret_ = this.j.l("maximizedPane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("maximizedPane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "f", {
        get: function () {
            var ret_ = this.j.l("resourceStrings", function (a) { return new DockManagerResourceStrings(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("resourceStrings", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "k", {
        get: function () {
            var ret_ = this.j.m("allowFloatingPanesResize");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("allowFloatingPanesResize", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "n", {
        get: function () {
            var ret_ = this.j.m("disableKeyboardNavigation");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("disableKeyboardNavigation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "l", {
        get: function () {
            var ret_ = this.j.m("allowInnerDock");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.u("allowInnerDock", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockManager.prototype.q = function (a) {
        this.nativeElement.focusPane(this.j.h(a));
    };
    DockManager.$t = markType(DockManager, 'DockManager', BaseElement.$);
    return DockManager;
}(BaseElement));
export { DockManager };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/DockManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { DockManagerLayout } from "./DockManagerLayout";
import { DockManagerPane } from "./DockManagerPane";
import { DockManagerPoint } from "./DockManagerPoint";
import { ContentPane } from "./ContentPane";
import { DockManagerShowHeaderIconOnHover_$type } from "./DockManagerShowHeaderIconOnHover";
import { DockManagerResourceStrings } from "./DockManagerResourceStrings";
import { LayoutChangeEventArgs } from "./LayoutChangeEventArgs";
/**
 * @hidden
 */
var DockManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockManager, _super);
    function DockManager() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.layoutChange = null;
        _this.i = new WCNativeHelper();
        _this.o = null;
        return _this;
    }
    DockManager.prototype.layoutChangeChanged = function () {
        var _this = this;
        if (this.layoutChange != null) {
            this.j.r("layoutChange", function (a) { return _this.layoutChange(_this, LayoutChangeEventArgs.b(_this.b)); }, false);
        }
        else {
            this.j.u("layoutChange");
        }
    };
    Object.defineProperty(DockManager.prototype, "j", {
        get: function () {
            return this.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "nativeElement", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.i.o = this.o;
        },
        enumerable: false,
        configurable: true
    });
    DockManager.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockManager.prototype, "b", {
        get: function () {
            var ret_ = this.j.m("layout", function (a) { return new DockManagerLayout(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("layout", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "c", {
        get: function () {
            var ret_ = this.j.m("draggedPane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("draggedPane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "e", {
        get: function () {
            var ret_ = this.j.m("dropPosition", function (a) { return new DockManagerPoint(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("dropPosition", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "a", {
        get: function () {
            var ret_ = this.j.m("activePane", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("activePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "m", {
        get: function () {
            var ret_ = this.j.n("allowMaximize");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("allowMaximize", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "g", {
        get: function () {
            var ret_ = this.j.n("showHeaderIconOnHover");
            ret_ = enumGetBox(DockManagerShowHeaderIconOnHover_$type, EnumUtil.getEnumValue(DockManagerShowHeaderIconOnHover_$type, this.j.f(DockManagerShowHeaderIconOnHover_$type, ret_)));
            return EnumUtil.getEnumValue(DockManagerShowHeaderIconOnHover_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DockManagerShowHeaderIconOnHover_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.j.v("showHeaderIconOnHover", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "d", {
        get: function () {
            var ret_ = this.j.m("maximizedPane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("maximizedPane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "f", {
        get: function () {
            var ret_ = this.j.m("resourceStrings", function (a) { return new DockManagerResourceStrings(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("resourceStrings", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "k", {
        get: function () {
            var ret_ = this.j.n("allowFloatingPanesResize");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("allowFloatingPanesResize", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "n", {
        get: function () {
            var ret_ = this.j.n("disableKeyboardNavigation");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("disableKeyboardNavigation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManager.prototype, "l", {
        get: function () {
            var ret_ = this.j.n("allowInnerDock");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.j.v("allowInnerDock", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockManager.prototype.q = function (a) {
        this.nativeElement.focusPane(this.j.i(a));
    };
    DockManager.$t = markType(DockManager, 'DockManager', BaseElement.$);
    return DockManager;
}(BaseElement));
export { DockManager };
